metadata(version="0.5.0")

require("ffilib")

module("time.py")
